// -*- C++ -*-
// File: pixmaps.c
//
// Created: Fri Jan  1 19:11:33 1999
//
// $Id: pixmaps.c,v 1.17 1999/10/14 13:32:15 yarick Exp $
//
#include <gtk/gtk.h>
#include <glib.h>
#include <gdk/gdk.h>
#include <stdlib.h>
#include <sys/stat.h>
#include <unistd.h>
#include "common.h"
#include "config.h"
#include "pixmaps.h"
#include "addons.h"

void
load_icons (void)
{
  GList *hGL1;
  GfbItemIcons *hGII1;
  GfbTypeDef *hGTD1;
  gchar *hgc1;
  gchar *path_to_icons;
  gchar *full_path;
  GtkStyle *main_style;
  GdkColor *transp_color;
  main_style = gtk_widget_get_style (main_window);
  transp_color = &main_style->bg[GTK_STATE_NORMAL];
  path_to_icons = g_malloc0 (PATH_MAX);
  full_path = g_malloc0 (PATH_MAX);
  strcpy (path_to_icons, getenv ("HOME"));
  append_slash (path_to_icons);
  strcat (path_to_icons, ICON_PATH);
  for (hGL1 = gfb_typedefs; hGL1 != NULL; hGL1 = g_list_next (hGL1))
    {
      hGII1 = g_malloc0 (sizeof (GfbItemIcons));
      hgc1 = find_action (hGL1->data, "Icon1");
      if (hgc1 != NULL)
	{
	  strcpy (full_path, path_to_icons);
	  strcat (full_path, hgc1);
	  hGII1->Icon1 = gdk_pixmap_create_from_xpm (
						      main_window->window,
						      &hGII1->Bitmap1,
						      transp_color,
						      full_path);
	};
      hgc1 = find_action (hGL1->data, "Icon2");
      if (hgc1 != NULL)
	{
	  strcpy (full_path, path_to_icons);
	  strcat (full_path, hgc1);
	  hGII1->Icon2 = gdk_pixmap_create_from_xpm (
						      main_window->window,
						      &hGII1->Bitmap2,
						      transp_color,
						      full_path);
	};
      GFB_TYPE_DEF (hGL1->data)->icons = hGII1;
    };
  g_free (full_path);
  g_free (path_to_icons);
}

void *
get_icons_pointer (UniversalItem *item)
{
  GfbItemIcons *hGII1;
  GfbTypeDef *hGTD1;
  g_return_val_if_fail (UNI_ITEM(item)->type != 0, NULL);
  switch (UNI_ITEM(item)->type & 0x3F)
    {
    case FILE_LIST_FILE:
      hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef ("FILE_LIST_FILE"))->icons);
      break;
    case FILE_LIST_DIR:
      hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef ("FILE_LIST_DIR"))->icons);
      break;
    case FILE_LIST_FILESYSTEM:
      hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef ("FILE_LIST_FILESYSTEM"))->icons);
      break;
    case TREE_NODE_WORLD:
      hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef ("TREE_NODE_WORLD"))->icons);
      break;
    case TREE_NODE_LOCALHOST:
      hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef ("TREE_NODE_LOCALHOST"))->icons);
      break;
    case TREE_NODE_NETWORK:
      hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef ("TREE_NODE_NETWORK"))->icons);
      break;
    case TREE_NODE_FILESYSTEM:
      hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef ("TREE_NODE_FILESYSTEM"))->icons);
      break;
    case TREE_NODE_DIR:
      hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef ("TREE_NODE_DIR"))->icons);
      break;

    default:
      hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef ("FILE_LIST_FILE"))->icons);
      break;
    };
  if ( UNI_ITEM(item)->type & GFB_EXECUTABLE )
        hGII1 = GFB_ITEM_ICONS (GFB_TYPE_DEF (find_typedef("GFB_EXECUTABLE"))->icons);
        else
  if ( (UNI_ITEM(item)->type & 0x3F) == FILE_LIST_FILE )
        {
                hGTD1 = find_typedef_by_substr(FILE_INFO(UNI_ITEM(item)->data)->name);
                if (hGTD1 != NULL)
                hGII1 = GFB_ITEM_ICONS(hGTD1->icons);
        };
  return hGII1;
}


GfbItemIcons *
add_symlink_sign (GdkPixmap * orig_pm, GdkBitmap * orig_bm, gint sl_type)
{
  /* All is straightforward */
  GdkGC *hGGC1, *hGGC2;
  GdkPixmap *hGP1, *hGP2;
  GdkBitmap *hGB1, *hGB2;
  GfbTypeDef *hGTD1;
  GfbItemIcons *hGII1;
  gint width, height;
  gint width1, height1;
  gint width2, height2;
  gint width3, height3;
  hGTD1 = NULL;
  hGII1 = NULL;
  hGGC1 = hGGC2 = NULL;
  hGB1 = hGB2 = NULL;
  hGP1 = hGP2 = NULL;
  width = height = width1 = height1 = width2 = height2 = width3 = height3 = 0;
  hGGC1 = gdk_gc_new (orig_pm);
  hGGC2 = gdk_gc_new (orig_bm);
  gdk_window_get_size (orig_pm, &width, &height);
  gdk_window_get_size (orig_bm, &width1, &height1);
  hGP1 = gdk_pixmap_new (main_window->window, width, height, -1);
  hGB1 = gdk_pixmap_new (NULL, width1, height1, 1);
  gdk_draw_pixmap (hGP1, hGGC1, orig_pm, 0, 0, 0, 0, width, height);
  gdk_draw_pixmap (hGB1, hGGC2, orig_bm, 0, 0, 0, 0, width1, height1);
  hGTD1 = GFB_TYPE_DEF (find_typedef ("GFB_SYMLINK"));
  hGII1 = GFB_ITEM_ICONS (hGTD1->icons);
  if (sl_type == 1)
    {
      hGP2 = hGII1->Icon1;
      hGB2 = hGII1->Bitmap1;
    }
  else
    {
      hGP2 = hGII1->Icon2;
      hGB2 = hGII1->Bitmap2;
    };
  gdk_window_get_size (hGP2, &width2, &height2);
  gdk_window_get_size (hGB2, &width3, &height3);
  gdk_draw_pixmap (hGP1, hGGC1, hGP2, 0, 0, 0, height - height2, width2, height2);
  gdk_draw_pixmap (hGB1, hGGC2, hGB2, 0, 0, 0, height1 - height3, width3, height3);
  hGII1 = g_malloc0 (sizeof (GfbItemIcons));
  hGII1->Icon1 = hGP1;
  hGII1->Bitmap1 = hGB1;
  gdk_gc_unref (hGGC1);
  gdk_gc_unref (hGGC2);
  return hGII1;
}





